Crate kcr_operations_kubeblocks_io

Crate kcr_operations_kubeblocks_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the operations.kubeblocks.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

operations.kubeblocks.io/v1alpha1

  • OpsDefinition
  • OpsRequest

Modules

v1alpha1